import type { VxeGridProps } from '#/adapter/vxe-table';

import { DictEnum } from '@vben/constants';
import { getPopupContainer } from '@vben/utils';

import { type FormSchemaGetter } from '#/adapter/form';
import { getDictOptions } from '#/utils/dict';
import { renderDict } from '#/utils/render';

export const querySchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    fieldName: 'equName',
    label: '设备名称'
  },
  {
    component: 'Input',
    fieldName: 'assetNo',
    label: '资产编号'
  }
];

export const columns: VxeGridProps['columns'] = [
  { type: 'checkbox', width: 60, fixed: 'left' },
  {
    title: '状态',
    field: 'status',
    minWidth: 80,
    slots: {
      default: ({ row }) => {
        return renderDict(row.status, DictEnum.EIMS_ORDITM_STATUS);
      }
    }
  },
  {
    title: '完成时间',
    field: 'itmTime',
    minWidth: 200
  },
  {
    title: '设备名称',
    field: 'equName',
    minWidth: 160,
    slots: { default: 'equName' }
  },
  {
    title: '保养项目',
    field: 'itmName',
    minWidth: 200
  },
  {
    title: '项目标准',
    field: 'itmAction',
    minWidth: 200
  },
  {
    title: '保养用户',
    field: 'itmUserName',
    minWidth: 200
  },
  {
    field: 'action',
    fixed: 'right',
    slots: { default: 'action' },
    title: '操作',
    width: 200
  }
];

export const drawerSchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    fieldName: 'orderId',
    label: '工单id',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    }
  },
  {
    component: 'Input',
    fieldName: 'orderName',
    label: '保养工单'
  },
  {
    component: 'Input',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    fieldName: 'id'
  },
  {
    component: 'Input',
    fieldName: 'equId',
    label: '设备id',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    }
  },
  {
    component: 'Input',
    fieldName: 'equName',
    label: '设备名称',
    componentProps: {
      readonly: true
    },
  },
  {
    component: 'Select',
    componentProps: {
      allowClear: true,
      showSearch: true,
      getPopupContainer
    },
    fieldName: 'itmName',
    label: '保养项目',
  },
  {
    component: 'Input',
    fieldName: 'itmAction',
    label: '项目标准',
    componentProps: {
      readonly: true
    },
  },
  {
    component: 'Input',
    fieldName: 'itmUser',
    label: '保养人id',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    }
  },
  {
    component: 'Input',
    fieldName: 'itmUserName',
    label: '保养人'
  },
  {
    component: 'RadioGroup',
    componentProps: {
      buttonStyle: 'solid',
      options: getDictOptions(DictEnum.EIMS_ORDITM_STATUS),
      optionType: 'button'
    },
    fieldName: 'status',
    defaultValue: '0',
    label: '状态'
  },
  {
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD HH:mm:ss',
      showTime: true,
      valueFormat: 'YYYY-MM-DD HH:mm:ss',
      getPopupContainer
    },
    fieldName: 'itmTime',
    label: '完成时间'
  },
  {
    component: 'Textarea',
    fieldName: 'remark',
    label: '备注'
  }
];
